@@ -205,22 +205,24 @@ class HandyHelperListPlusCreateView(HandyHelperGenericBaseListView):
     A reusable generic base view to render a ListView where the child view will provide a html table and create form.
 
     class parameters:
-        base_template          - base template used for rendering page; defaults to: handyhelpers_base.htm
-        template_name          - template used when rendering page; defaults to: handyhelpers/generic/generic_list.html
-        args                   - additional args to pass into the template
-        kwargs                 - additional kwargs to pass into the template
-        queryset               - queryset to be rendered on the page
-        title                  - title to use in template
-        page_description       - subtitle to use in template
-        table                  - htm file rendering the queryset to be included in the generic_list template
-        modals                 - htm file rendering additional modals to be included in the generic_list template
+        base_template            - base template used for rendering page; defaults to: handyhelpers_base.htm
+        template_name            - template used when rendering page; defaults to: handyhelpers/generic/generic_list.html
+        args                     - additional args to pass into the template
+        kwargs                   - additional kwargs to pass into the template
+        queryset                 - queryset to be rendered on the page
+        title                    - title to use in template
+        page_description         - subtitle to use in template
+        table                    - htm file rendering the queryset to be included in the generic_list template
+        modals                   - htm file rendering additional modals to be included in the generic_list template
 
-        create_form_obj        - form object
-        create_form_url        - url the form (action) should post to
-        create_form_title      - title to use on the create form modal (can be html)
-        create_form_modal      - name of modal for the create form
-        create_form_link_title - text used for the link opening the create form
-        create_form_tool_tip   - text to use for the tooltip
+        create_form_obj          - form object
+        create_form_url          - url the form (action) should post to
+        create_form_title        - title to use on the create form modal (can be html)
+        create_form_modal        - name of modal for the create form
+        create_form_modal_size   - bootstrap modal size class (such as modal-lg)
+        create_form_link_title   - text used for the link opening the create form
+        create_form_tool_tip     - text to use for the tooltip
+        create_form_autocomplete - autocomplete parameter to use in form tag (on/off)
 
     example:
         class ListProjects(HandyHelperBaseCreateListView):
@@ -233,6 +235,7 @@ class HandyHelperListPlusCreateView(HandyHelperGenericBaseListView):
             create_form_url = '/hostmgr/create_project/'
             create_form_title = '<b>Add Project: </b><small> </small>'
             create_form_modal = 'add_project'
+            create_form_modal_size = 'modal-lg'
             create_form_link_title = 'add project'
             create_form_tool_tip = 'add project'
     """
@@ -242,8 +245,10 @@ class HandyHelperListPlusCreateView(HandyHelperGenericBaseListView):
     create_form_url = None
     create_form_title = None
     create_form_modal = None
+    create_form_modal_size = None
     create_form_link_title = None
     create_form_tool_tip = None
+    create_form_autocomplete = None
 
     def get(self, request, *args, **kwargs):
         context = dict(base_template=self.base_template, queryset=self.filter_by_query_params(), title=self.title,
@@ -256,8 +261,10 @@ class HandyHelperListPlusCreateView(HandyHelperGenericBaseListView):
             self.create_form['action_url'] = self.create_form_url
             self.create_form['title'] = self.create_form_title
             self.create_form['modal_name'] = self.create_form_modal
+            self.create_form['modal_size'] = self.create_form_modal_size
             self.create_form['link_title'] = self.create_form_link_title
             self.create_form['tool_tip'] = self.create_form_tool_tip
+            self.create_form['autocomplete'] = self.create_form_autocomplete
             context['create_form'] = self.create_form
         return render(request, self.template_name, context)
 
@@ -272,23 +279,25 @@ class HandyHelperListPlusFilterView(HandyHelperGenericBaseListView):
     A reusable generic base view to render a ListView where the child view will provide a html table and filter form.
 
     class parameters:
-        base_template          - base template used for rendering page; defaults to: handyhelpers_base.htm
-        template_name          - template used when rendering page; defaults to: handyhelpers/generic/generic_list.html
-        args                   - additional args to pass into the template
-        kwargs                 - additional kwargs to pass into the template
-        queryset               - queryset to be rendered on the page
-        title                  - title to use in template
-        page_description       - subtitle to use in template
-        table                  - htm file rendering the queryset to be included in the generic_list template
-        modals                 - htm file rendering additional modals to be included in the generic_list template
+        base_template            - base template used for rendering page; defaults to: handyhelpers_base.htm
+        template_name            - template used when rendering page; defaults to: handyhelpers/generic/generic_list.html
+        args                     - additional args to pass into the template
+        kwargs                   - additional kwargs to pass into the template
+        queryset                 - queryset to be rendered on the page
+        title                    - title to use in template
+        page_description         - subtitle to use in template
+        table                    - htm file rendering the queryset to be included in the generic_list template
+        modals                   - htm file rendering additional modals to be included in the generic_list template
 
-        filter_form_obj        - form object
-        filter_form_url        - url the form (action) should post to
-        filter_form_title      - title to use on the filter form modal (can be html)
-        filter_form_modal      - name of modal for the filter form
-        filter_form_link_title - text used for the link opening the filter form
-        filter_form_tool_tip   - text to use for the tooltip
-        filter_form_undo = True
+        filter_form_obj          - form object
+        filter_form_url          - url the form (action) should post to
+        filter_form_title        - title to use on the filter form modal (can be html)
+        filter_form_modal        - name of modal for the filter form
+        filter_form_modal_size   - bootstrap modal size class (such as modal-lg)
+        filter_form_link_title   - text used for the link opening the filter form
+        filter_form_tool_tip     - text to use for the tooltip
+        filter_form_undo         - True
+        filter_form_autocomplete - autocomplete parameter to use in form tag (on/off)
 
     example:
         class ListProjects(HandyHelperListPlusFilterView):
@@ -301,6 +310,7 @@ class HandyHelperListPlusFilterView(HandyHelperGenericBaseListView):
             filter_form_url = '/hostmgr/filter_project/'
             filter_form_title = '<b>Filter Projects: </b><small> </small>'
             filter_form_modal = 'filter_project'
+            filter_form_modal_size = 'modal-lg'
             filter_form_link_title = 'filter project'
             filter_form_tool_tip = 'filter project'
     """
@@ -310,9 +320,11 @@ class HandyHelperListPlusFilterView(HandyHelperGenericBaseListView):
     filter_form_url = '/handyhelpers/filter_list_view'
     filter_form_title = None
     filter_form_modal = None
+    filter_form_modal_size = None
     filter_form_link_title = None
     filter_form_tool_tip = None
     filter_form_undo = True
+    filter_form_autocomplete = None
 
     def get(self, request, *args, **kwargs):
         context = dict(base_template=self.base_template, queryset=self.filter_by_query_params(), title=self.title,
@@ -325,9 +337,11 @@ class HandyHelperListPlusFilterView(HandyHelperGenericBaseListView):
             self.filter_form['action_url'] = self.filter_form_url
             self.filter_form['title'] = self.filter_form_title
             self.filter_form['modal_name'] = self.filter_form_modal
+            self.filter_form['modal_size'] = self.filter_form_modal_size
             self.filter_form['link_title'] = self.filter_form_link_title
             self.filter_form['tool_tip'] = self.filter_form_tool_tip
             self.filter_form['undo'] = self.filter_form_undo
+            self.filter_form['autocomplete'] = self.filter_form_autocomplete
             context['filter_form'] = self.filter_form
         return render(request, self.template_name, context)
 
@@ -338,30 +352,34 @@ class HandyHelperListPlusCreateAndFilterView(HandyHelperGenericBaseListView):
     and a create form and a filter form.
 
     class parameters:
-        base_template          - base template used for rendering page; defaults to: handyhelpers_base.htm
-        template_name          - template used when rendering page; defaults to: handyhelpers/generic/generic_list.html
-        args                   - additional args to pass into the template
-        kwargs                 - additional kwargs to pass into the template
-        queryset               - queryset to be rendered on the page
-        title                  - title to use in template
-        page_description       - subtitle to use in template
-        table                  - htm file rendering the queryset to be included in the generic_list template
-        modals                 - htm file rendering additional modals to be included in the generic_list template
+        base_template            - base template used for rendering page; defaults to: handyhelpers_base.htm
+        template_name            - template used when rendering page; defaults to: handyhelpers/generic/generic_list.html
+        args                     - additional args to pass into the template
+        kwargs                   - additional kwargs to pass into the template
+        queryset                 - queryset to be rendered on the page
+        title                    - title to use in template
+        page_description         - subtitle to use in template
+        table                    - htm file rendering the queryset to be included in the generic_list template
+        modals                   - htm file rendering additional modals to be included in the generic_list template
 
-        create_form_obj        - create form object
-        create_form_url        - url the create form (action) should post to
-        create_form_title      - title to use on the create form modal (can be html)
-        create_form_modal      - name of modal for the create form
-        create_form_link_title - text used for the link opening the create form
-        create_form_tool_tip   - text to use for the create form link tooltip
+        create_form_obj          - create form object
+        create_form_url          - url the create form (action) should post to
+        create_form_title        - title to use on the create form modal (can be html)
+        create_form_modal        - name of modal for the create form
+        create_form_modal_size   - bootstrap modal size class (such as modal-lg)
+        create_form_link_title   - text used for the link opening the create form
+        create_form_tool_tip     - text to use for the create form link tooltip
+        create_form_autocomplete - autocomplete parameter to use in form tag (on/off)
 
-        filter_form_obj        - filter form object
-        filter_form_url        - url the filter form (action) should post to
-        filter_form_title      - title to use on the filter form modal (can be html)
-        filter_form_modal      - name of modal for the filter form
-        filter_form_link_title - text used for the link opening the filter form
-        filter_form_tool_tip   - text to use for the filter form link tooltip
-        filter_form_undo       - include an undo icon to clear applied filters
+        filter_form_obj          - filter form object
+        filter_form_url          - url the filter form (action) should post to
+        filter_form_title        - title to use on the filter form modal (can be html)
+        filter_form_modal        - name of modal for the filter form
+        filter_form_modal_size   - bootstrap modal size class (such as modal-lg)
+        filter_form_link_title   - text used for the link opening the filter form
+        filter_form_tool_tip     - text to use for the filter form link tooltip
+        filter_form_undo         - include an undo icon to clear applied filters
+        filter_form_autocomplete - autocomplete parameter to use in form tag (on/off)
 
     example:
         class ListProjects(HandyHelperBaseCreateListView):
@@ -390,17 +408,21 @@ class HandyHelperListPlusCreateAndFilterView(HandyHelperGenericBaseListView):
     create_form_url = None
     create_form_title = None
     create_form_modal = None
+    create_form_modal_size = None
     create_form_link_title = None
     create_form_tool_tip = None
+    create_form_autocomplete = None
 
     filter_form = dict()
     filter_form_obj = None
     filter_form_url = '/handyhelpers/filter_list_view'
     filter_form_title = None
     filter_form_modal = None
+    filter_form_modal_size = None
     filter_form_link_title = None
     filter_form_tool_tip = None
     filter_form_undo = True
+    filter_form_autocomplete = None
 
     def get(self, request, *args, **kwargs):
         context = dict(base_template=self.base_template, queryset=self.filter_by_query_params(), title=self.title,
@@ -412,8 +434,10 @@ class HandyHelperListPlusCreateAndFilterView(HandyHelperGenericBaseListView):
             self.create_form['action_url'] = self.create_form_url
             self.create_form['title'] = self.create_form_title
             self.create_form['modal_name'] = self.create_form_modal
+            self.create_form['modal_size'] = self.create_form_modal_size
             self.create_form['link_title'] = self.create_form_link_title
             self.create_form['tool_tip'] = self.create_form_tool_tip
+            self.create_form['autocomplete'] = self.create_form_autocomplete
             context['create_form'] = self.create_form
 
         if self.filter_form_obj:
@@ -422,9 +446,11 @@ class HandyHelperListPlusCreateAndFilterView(HandyHelperGenericBaseListView):
             self.filter_form['action_url'] = self.filter_form_url
             self.filter_form['title'] = self.filter_form_title
             self.filter_form['modal_name'] = self.filter_form_modal
+            self.filter_form['modal_size'] = self.filter_form_modal_size
             self.filter_form['link_title'] = self.filter_form_link_title
             self.filter_form['tool_tip'] = self.filter_form_tool_tip
             self.filter_form['undo'] = self.filter_form_undo
+            self.filter_form['autocomplete'] = self.filter_form_autocomplete
             context['filter_form'] = self.filter_form
 
         return render(request, self.template_name, context)
